.. :changelog:

History
-------

0.1.0 (2013-11-25)
++++++++++++++++++

* First release on PyPI.

0.1.1 (2013-11-25)
++++++++++++++++++

* Basic documentation.

0.2.0 (2013-12-8)
++++++++++++++++++

* Added replacement for bootstrap_toolkit's as_bootstrap template filter. The reform template tag passed the original template context to the form templates enabling checks for instance for permissions etc.

0.2.1 (2013-12-8)
++++++++++++++++++

* Added bootstrp CDN.